summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2008-12-07 01:50:16 +0000
committerChris Lattner <sabre@nondot.org>2008-12-07 01:50:16 +0000
commite79be944c8ced0a0cb80ede8cb9f97e4fdc6778f (patch)
tree3b13711b8b584f5764ab31e81bbe29db1cfb20e3 /include
parentd8dd934d16d1190881d45b065daec4a1ba82133f (diff)
downloadllvm-e79be944c8ced0a0cb80ede8cb9f97e4fdc6778f.tar.gz
llvm-e79be944c8ced0a0cb80ede8cb9f97e4fdc6778f.tar.bz2
llvm-e79be944c8ced0a0cb80ede8cb9f97e4fdc6778f.tar.xz
push the "pointer case" up the analysis stack a bit. This causes
duplication of logic (in 2 places) to determine what pointer a load/store touches. This will be addressed in a future commit. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@60648 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/llvm/Analysis/MemoryDependenceAnalysis.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/include/llvm/Analysis/MemoryDependenceAnalysis.h b/include/llvm/Analysis/MemoryDependenceAnalysis.h
index e61a431200..40c445c412 100644
--- a/include/llvm/Analysis/MemoryDependenceAnalysis.h
+++ b/include/llvm/Analysis/MemoryDependenceAnalysis.h
@@ -220,11 +220,13 @@ namespace llvm {
private:
/// getDependencyFrom - Return the instruction on which the memory operation
/// 'QueryInst' depends. This starts scanning from the instruction before
/// the position indicated by ScanIt.
- MemDepResult getDependencyFrom(Instruction *QueryInst,
- BasicBlock::iterator ScanIt, BasicBlock *BB);
+ MemDepResult getPointerDependencyFrom(Value *Pointer, uint64_t MemSize,
+ bool isLoad,
+ BasicBlock::iterator ScanIt,
+ BasicBlock *BB);
MemDepResult getCallSiteDependencyFrom(CallSite C,
BasicBlock::iterator ScanIt,
BasicBlock *BB);
@@ -220,11 +220,13 @@ namespace llvm {
private:
- /// getDependencyFrom - Return the instruction on which the memory operation
- /// 'QueryInst' depends. This starts scanning from the instruction before
+ /// getDependencyFrom - Return the instruction on which the memory location
+ /// '*Pointer' depends. This starts scanning from the instruction before
/// the position indicated by ScanIt.